@@ -23,11 +23,7 @@
 #include <kdebug.h>
 #include <tdeglobalsettings.h>
 #include <tdeversion.h>
-#if TDE_VERSION_MAJOR >= 3
-  #include <tdeapplication.h>
-#else
-  #include <kapp.h>
-#endif
+#include <tdeapplication.h>
 
 
 BoldMenuItem::BoldMenuItem(const TQString &text, const TQColor &active_text_color,
